Module registry

Module registry 

Available on crate feature threads only.
Building blocks for runtimes and thread-aware hosts.

Structs

ThreadRegistry
A registry for managing pinning threads to specific processors.

Enums

ProcessorCount
The number of processors to use for the registry.