pub fn closure_mut<T, D>(data: D, f: fn(&mut D) -> T) -> ClosureMut<T, D>where
D: ThreadAware,Expand description
Constructs a ClosureMut.
Create a closure-like object by explicitly providing closed-over
value and a function pointer to operate on that value, essentially simulating a
parameterless closure that ensures that captured data implements ThreadAware.