pub trait ThreadAwareFnMut<T>: ThreadAware {
// Required method
fn call_mut(&mut self) -> T;
}Expand description
Marks FnMut()-like closure whose captured values all implement ThreadAware.
This trait is used to define closures that can be called mutably, allowing the closure to modify its internal state.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".